/* globals bryntum: true */
import { LightningElement } from 'lwc';
import { ShowToastEvent } from "lightning/platformShowToastEvent";
import { loadScript, loadStyle } from "lightning/platformResourceLoader";
import CALENDAR from "@salesforce/resourceUrl/calendar";

export default class Calendar_component extends LightningElement {
    idCount = 0;
    get calendarElt() {
        return this.template.querySelector('div.container');
    }

    renderedCallback() {
        if (this.bryntumInitialized) {
            return;
        }
        this.bryntumInitialized = true;

        Promise.all([
            loadScript(this, CALENDAR + "/calendar.lwc.module.min.js"),
            loadStyle(this, CALENDAR + "/calendar.stockholm.min.css")
        ])
            .then(() => {
                this.createCalendar();
            })
            .catch(error => {
                this.dispatchEvent(
                    new ShowToastEvent({
                        title: "Error loading Bryntum Calendar",
                        message: error,
                        variant: "error"
                    })
                );
            });
    }

    createCalendar() {
        const calendar = new bryntum.calendar.Calendar({
            appendTo: this.calendarElt,
            height: 900,
            width: '100%',
            title: 'December 2022',
            date: new Date(2022, 12, 12),
            hideNonWorkingDays: false,
            weekStartDay: 0,
            nonWorkingDays: {
                0: true, // Only Sunday is non-working day
                6: true
            },
            modes: {
                day: null,
                agenda: null,
                year: null
            },
            sidebar: {
                items: {
                    viewSelector: {
                        type: 'combo',
                        displayField: 'name',
                        store: {
                            fields: ['type', 'name'],
                            data: [
                              { id: '1', name: 'forty one' }, 
                              { id: '2', name: 'cool cool' },
                              { id: '3', name: 'cool 1' },
                              { id: '4', name: 'cool 2' },
                              { id: '5', name: 'cool 3' },
                              { id: '6', name: 'cool 4' },
                              { id: '7', name: 'forty one' }, 
                              { id: '8', name: 'cool cool' },
                              { id: '9', name: 'cool 1' },
                              { id: '10', name: 'cool 2' },
                              { id: '11', name: 'cool 3' },
                              { id: '12', name: 'cool 4' },
                            ],
                        },
                        editable: false,
                    }
                }
            }
        });
        this.eventStore = calendar.eventStore;
        return calendar;
    }
}
